"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@typescript-eslint/utils");
const suggestCustomLoggerRule = {
    defaultOptions: [],
    meta: {
        type: "suggestion",
        messages: {
            customLoggerNotUsedForLog: "Log를 위해 customLogger가 사용되지 않았습니다.",
            customLoggerNotUsedForError: "Error Log를 위해 customLogger가 사용되지 않았습니다.",
        },
        fixable: "code",
        schema: [],
    },
    create: (context) => ({
        CallExpression: (node) => {
            const callee = node.callee;
            if (callee.type === utils_1.AST_NODE_TYPES.MemberExpression &&
                callee.object.type === utils_1.AST_NODE_TYPES.Identifier &&
                callee.object.name === "console" &&
                callee.property.type === utils_1.AST_NODE_TYPES.Identifier) {
                if (callee.property.name === "log") {
                    context.report({
                        node,
                        messageId: "customLoggerNotUsedForLog",
                    });
                }
                if (callee.property.name === "error") {
                    context.report({
                        node,
                        messageId: "customLoggerNotUsedForError",
                    });
                }
            }
        },
    }),
};
exports.default = suggestCustomLoggerRule;
